@@ -12,7 +12,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 
 our $Debug = 0;
 
-our $VERSION = '0.770';
+our $VERSION = '0.771';
 
 __PACKAGE__->default_auto_method_types(qw(find get_set_on_save add_on_save));
 
@@ -105,6 +105,10 @@ __PACKAGE__->method_maker_info
 
 sub type { 'one to many' }
 
+sub is_singular { 0 }
+
+sub foreign_class { shift->class(@_) }
+
 *map_column = \&key_column;
 *column_map = \&key_columns;
 
@@ -262,6 +266,10 @@ For the method type "count", the relationship's L<name|Rose::DB::Object::Metadat
 
 Otherwise, undef is returned.
 
+=item B<is_singular>
+
+Returns false.
+
 =item B<manager_class [CLASS]>
 
 Get or set the name of the L<Rose::DB::Object::Manager>-derived class used to fetch objects.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<Rose::DB::Object::Manager> if this value is left undefined.
